#!/usr/bin/env python
# -*- coding: utf-8 -*-
from distutils.core import setup

setup(
  name = 'pymmh3',
  packages = ['pymmh3'],
  version = '0.0.2',
  license='CC0 1.0',
  description = 'Pure python mmh3 implementation compatiuble with python2 and python3',
  author = 'Ali Ahmed',
  author_email = 'alahmed.se@gmail.com',
  url = 'https://github.com/aahmed-se',
  keywords = ['mmh3', 'hashing'],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Utilities',
    'License :: OSI Approved :: Common Public License',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)